@@ -1,3 +1,5 @@
+import threading
+
 import regex
 import yarl
 
@@ -6,12 +8,38 @@ from ...helper import uwu
 CONTENT_ID_REGEX = regex.compile(r"embed-6/([^?#&/.]+)")
 
 
+parent_thread = threading.current_thread()
+ws_lock = threading.Lock()
+
+sid_holder = {
+    "sid": None,
+}
+
+active_event = threading.Event()
+
+
 def extract(session, url, **opts):
+
     from .polling import ws_stimulation
 
-    while ws_stimulation.session_sid is None:
+    if sid_holder["sid"] is None and not active_event.is_set():
+        active_event.set()
+
+        threading.Thread(
+            target=ws_stimulation,
+            kwargs={
+                "session": session,
+                "close_event": active_event,
+                "sid_holder": sid_holder,
+                "parent_thread": parent_thread,
+            },
+        ).start()
+
+    while sid_holder["sid"] is None:
         pass
 
+    sid = sid_holder["sid"]
+
     content_id = CONTENT_ID_REGEX.search(url).group(1)
     recaptcha_response = uwu.bypass_recaptcha(session, url, opts["headers"])
 
@@ -35,14 +63,14 @@ def extract(session, url, **opts):
             yield {
                 "stream_url": _.get("file"),
                 "subtitle": subtitles,
-                "headers": {"SID": ws_stimulation.session_sid},
+                "headers": {"SID": sid},
             }
 
         for _ in sources.get("sourcesBackup"):
             yield {
                 "stream_url": _.get("file"),
                 "subtitle": subtitles,
-                "headers": {"SID": ws_stimulation.session_sid},
+                "headers": {"SID": sid},
             }
 
     return list(yielder())
